@@ -6,35 +6,24 @@ Documents
 from __future__ import division, print_function, unicode_literals
 
 # Standard Library
-import logging
 import os
 import re
 import warnings
 from functools import partial
 
 # Third Party
+import requests
 from future.utils import python_2_unicode_compatible
-from requests.exceptions import RequestException
 
 # Local
 from .annotations import AnnotationClient
 from .base import APIResults, BaseAPIClient, BaseAPIObject
 from .constants import BULK_LIMIT
-from .exceptions import APIError
 from .organizations import Organization
 from .sections import SectionClient
-from .toolbox import grouper, is_url, merge_dicts, requests_retry_session
+from .toolbox import grouper, is_url, merge_dicts
 from .users import User
 
-try:
-    from urllib.parse import urlparse
-except ImportError:
-    from urlparse import urlparse
-
-
-
-logger = logging.getLogger("documentcloud")
-
 
 @python_2_unicode_compatible
 class Document(BaseAPIObject):
@@ -46,9 +35,8 @@ class Document(BaseAPIObject):
         "data",
         "description",
         "language",
-        "publish_at",
-        "published_url",
         "related_article",
+        "published_url",
         "source",
         "title",
     ]
@@ -127,7 +115,7 @@ class Document(BaseAPIObject):
 
     @property
     def mentions(self):
-        if hasattr(self, "highlights") and self.highlights is not None:
+        if hasattr(self, "highlights"):
             return [
                 Mention(page, text)
                 for page, texts in self.highlights.items()
@@ -163,20 +151,9 @@ class Document(BaseAPIObject):
         return self.organization.slug
 
     def _get_url(self, url, text):
-        base_netloc = urlparse(self._client.base_uri).netloc
-        url_netloc = urlparse(url).netloc
-
-        if base_netloc == url_netloc:
-            # if the url host is the same as the base api host,
-            # sent the request with the client in order to include
-            # authentication credentials
-            response = self._client.get(url, full_url=True)
-        else:
-            response = requests_retry_session().get(
-                url, headers={"User-Agent": "python-documentcloud2"}
-            )
+        response = requests.get(url, headers={"User-Agent": "python-documentcloud2"})
         if text:
-            return response.text
+            return response.content.decode("utf8")
         else:
             return response.content
 
@@ -205,10 +182,6 @@ class Document(BaseAPIObject):
             self.get_image_url(page=i, size=size) for i in range(1, self.page_count + 1)
         ]
 
-    def process(self):
-        """Reprocess the document"""
-        self._client.post("{}/{}/process/".format(self.api_path, self.id))
-
 
 class DocumentClient(BaseAPIClient):
     """Client for interacting with Documents"""
@@ -219,9 +192,13 @@ class DocumentClient(BaseAPIClient):
     def search(self, query, **params):
         """Return documents matching a search query"""
 
-        # legacy parameter mentions renamed to hl
         mentions = params.pop("mentions", None)
-        params["hl"] = mentions
+        if mentions is not None:  # pragma: no cover
+            warnings.warn(
+                "The `mentions` argument to `search` is deprecated, "
+                "it will always include mentions from all pages now",
+                DeprecationWarning,
+            )
         data = params.pop("data", None)
         if data is not None:  # pragma: no cover
             warnings.warn(
@@ -267,9 +244,7 @@ class DocumentClient(BaseAPIClient):
             "access",
             "description",
             "language",
-            "original_extension",
             "related_article",
-            "publish_at",
             "published_url",
             "source",
             "title",
@@ -319,7 +294,7 @@ class DocumentClient(BaseAPIClient):
         # upload the file directly to storage
         create_json = response.json()
         presigned_url = create_json["presigned_url"]
-        response = requests_retry_session().put(presigned_url, data=file_.read())
+        response = requests.put(presigned_url, data=file_.read())
 
         # begin processing the document
         doc_id = create_json["id"]
@@ -342,7 +317,7 @@ class DocumentClient(BaseAPIClient):
             )
         return path_list
 
-    def upload_directory(self, path, handle_errors=False, **kwargs):
+    def upload_directory(self, path, **kwargs):
         """Upload all PDFs in a directory"""
 
         # do not set the same title for all documents
@@ -351,80 +326,34 @@ class DocumentClient(BaseAPIClient):
         # Loop through the path and get all the files
         path_list = self._collect_files(path)
 
-        logger.info(
-            "Upload directory on %s: Found %d files to upload", path, len(path_list)
-        )
-
         # Upload all the pdfs using the bulk API to reduce the number
         # of API calls and improve performance
         obj_list = []
         params = self._format_upload_parameters("", **kwargs)
-        for i, pdf_paths in enumerate(grouper(path_list, BULK_LIMIT)):
+        for pdf_paths in grouper(path_list, BULK_LIMIT):
             # Grouper will put None's on the end of the last group
             pdf_paths = [p for p in pdf_paths if p is not None]
 
-            logger.info("Uploading group %d: %s", i + 1, "\n".join(pdf_paths))
-
             # create the documents
-            logger.info("Creating the documents...")
-            try:
-                response = self.client.post(
-                    "documents/",
-                    json=[
-                        merge_dicts(params, {"title": self._get_title(p)})
-                        for p in pdf_paths
-                    ],
-                )
-            except (APIError, RequestException) as exc:
-                if handle_errors:
-                    logger.info(
-                        "Error creating the following documents: %s %s",
-                        exc,
-                        "\n".join(pdf_paths),
-                    )
-                    continue
-                else:
-                    raise
+            response = self.client.post(
+                "documents/",
+                json=[
+                    merge_dicts(params, {"title": self._get_title(p)})
+                    for p in pdf_paths
+                ],
+            )
 
             # upload the files directly to storage
             create_json = response.json()
             obj_list.extend(create_json)
             presigned_urls = [j["presigned_url"] for j in create_json]
             for url, pdf_path in zip(presigned_urls, pdf_paths):
-                logger.info("Uploading %s to S3...", pdf_path)
-                try:
-                    response = requests_retry_session().put(
-                        url, data=open(pdf_path, "rb").read()
-                    )
-                    self.client.raise_for_status(response)
-                except (APIError, RequestException) as exc:
-                    if handle_errors:
-                        logger.info(
-                            "Error uploading the following document: %s %s",
-                            exc,
-                            pdf_path,
-                        )
-                        continue
-                    else:
-                        raise
+                response = requests.put(url, data=open(pdf_path, "rb").read())
+                self.client.raise_for_status(response)
 
             # begin processing the documents
-            logger.info("Processing the documents...")
             doc_ids = [j["id"] for j in create_json]
-            try:
-                response = self.client.post("documents/process/", json={"ids": doc_ids})
-            except (APIError, RequestException) as exc:
-                if handle_errors:
-                    logger.info(
-                        "Error creating the following documents: %s %s",
-                        exc,
-                        "\n".join(pdf_paths),
-                    )
-                    continue
-                else:
-                    raise
-
-        logger.info("Upload directory complete")
+            response = self.client.post("documents/process/", json={"ids": doc_ids})
 
         # Pass back the list of documents
         return [Document(self.client, d) for d in obj_list]
